==> ezplugins-1.3.2.tar.gz: ezplugins-1.3.2/tests/t10_basic/plugins/plugin8_call_parameters.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (C) 2019-2021, AllWorldIT.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""EZPlugins tests - Plugins for tests."""

from typing import Any, Dict

import ezplugins

__all__ = [
    "Plugin8",
]


@ezplugins.ezplugin
class Plugin8:  # pylint: disable=too-few-public-methods
    """Test plugin 8."""

    @ezplugins.ezplugin_method()
    def test_func_with_params1(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
        """Test function."""
        output = {
            "name": f"{self.__module__}.{__name__}#{self.__class__.__name__}",
            "args": args,
            "kwargs": kwargs,
        }
        return output

==> ezplugins-1.3.5.tar.gz: ezplugins-1.3.5/tests/t10_basic/plugins/plugin8_call_parameters.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (C) 2019-2022, AllWorldIT.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

"""EZPlugins tests - Plugins for tests."""

from typing import Any

import ezplugins

__all__ = [
    "Plugin8",
]


@ezplugins.ezplugin
class Plugin8:  # pylint: disable=too-few-public-methods
    """Test plugin 8."""

    @ezplugins.ezplugin_method()
    def test_func_with_params1(self, *args: Any, **kwargs: Any) -> dict[str, Any]:
        """Test function."""
        output = {
            "name": f"{self.__module__}.{__name__}#{self.__class__.__name__}",
            "args": args,
            "kwargs": kwargs,
        }
        return output
